@@ -5,39 +5,50 @@
 
 #' Authentication Endpoints
 #'
-#' Interact with authentication endpoints. Every call to the Cytobank API must be accompanied by an authentication token. Tokens should be kept secure as they confer access to the data and analyses of an account. Tokens expire after 8 hours by default but this figure my change depending on custom configurations of an Enterprise Cytobank. Use the authentication.logout / authentication.revoke API endpoints to invalidate one or all tokens for a user account.
+#' Interact with authentication endpoints. Every call to the Cytobank API
+#' must be accompanied by an authentication token. Tokens should be kept secure
+#' as they confer access to the data and analyses of an account. Tokens expire
+#' after 8 hours by default but this figure my change depending on custom
+#' configurations of an Enterprise Cytobank.
+#'
 #' @name authentication
-#' @param auth_token character representing Cytobank user's authentication token (expires in 8 hours)
-#' @param long_timeout numeric representing long request timeout times (default = 30s) \strong{[optional]}
+#' @param auth_token character representing Cytobank user's authentication token
+#'   (expires in 8 hours)
+#' @param long_timeout numeric representing long request timeout times (default
+#'   = 60s) \strong{[optional]}
 #' @param password character representing Cytobank user's password
-#' @param short_timeout numeric representing short request timeout times (default = 60s) \strong{[optional]}
+#' @param short_timeout numeric representing short request timeout times
+#'   (default = 30s) \strong{[optional]}
 #' @param site character representing Cytobank user's site, as in 'site'.cytobank.org. If your Cytobank server does not end in '.org', enter the entire server name, as in 'site.cytobank.cn'.
-#' @param timeout integer representing the request timeout time in seconds \strong{[optional]}
+#' @param timeout integer representing the request timeout time in seconds
+#'   \strong{[optional]}
+#' @param user_id integer representing Cytobank user's ID
 #' @param username character representing Cytobank user's username or email
-#' @param user_id integer representing a Cytobank user's ID
 #' @param UserSession Cytobank UserSession object
 
-
 #' @rdname authentication
 #'
-#' @details \code{authenticate} Authenticate a Cytobank user and returns a Cytobank UserSession object that is passed to all other Cytobank API endpoints.
+#' @details \code{authenticate} Authenticate a Cytobank user and return a
+#'   Cytobank UserSession object that is passed to all other Cytobank API
+#'   endpoints.
 #' @examples \dontrun{# Authenticate via username/password
-#' cyto_session <- authenticate(site="premium", username="cyril_cytometry", password="cytobank_rocks!")
-#' # Authenticate via auth_token
+#' cyto_session <- authenticate(site="premium", username="cyril_cytometry",
+#' password="cytobank_rocks!") # Authenticate via auth_token
 #' cyto_session <- authenticate(site="premium", auth_token="my_secret_auth_token")
 #' }
 #' @export
 authenticate <- function(site, username=NA, password=NA, auth_token=NA, short_timeout=30, long_timeout=60, timeout=30)
 {
-
     site_fullname = ifelse(grepl('\\.cytobank.\\w', site),
-                           site,
-                           paste0(site, '.cytobank.org'))
+                  site,
+                  paste0(site, '.cytobank.org'))
 
     if (!is.na(auth_token))
     {
+        user_id <- c(jsonlite::fromJSON(rawToChar(jose::base64url_decode(unlist(strsplit(auth_token,".",fixed = TRUE))[2]))))$user_id
+
         return(new("UserSession", auth_token=auth_token, site=paste("https://", site_fullname, "/cytobank/api/v1", sep=""),
-                   short_timeout=short_timeout, long_timeout=long_timeout))
+                   short_timeout=short_timeout, long_timeout=long_timeout, user_id=as.integer(user_id)))
     }
 
     # Authenticate user
@@ -49,8 +60,8 @@ authenticate <- function(site, username=NA, password=NA, auth_token=NA, short_ti
 
     parsed <- parse(resp, "authentication")
 
-    return(new("UserSession", auth_token=parsed$user$authToken, site=paste("https://", site, ".cytobank.org/cytobank/api/v1", sep=""),
-               short_timeout=short_timeout, long_timeout=long_timeout))
+    return(new("UserSession", auth_token=parsed$user$authToken, site=paste("https://", site_fullname, "/cytobank/api/v1", sep=""),
+               short_timeout=short_timeout, long_timeout=long_timeout, user_id=as.integer(parsed$user$id)))
 }
 
 
@@ -61,18 +72,23 @@ setGeneric("authentication.logout", function(UserSession, timeout=UserSession@sh
 #' @rdname authentication
 #' @aliases authentication.logout
 #'
-#' @details \code{authentication.logout} Logout a Cytobank user.
-#' @examples \dontrun{authentication.logout(cyto_session)
-#' }
+#' @details \code{authentication.logout} This function has been deprecated. Logout a Cytobank user.
+
 #' @export
 setMethod("authentication.logout", signature(UserSession="UserSession"), function(UserSession, timeout=UserSession@short_timeout)
 {
-    resp <- POST(paste(UserSession@site, "/logout", sep=""),
-                 add_headers(Authorization=paste("Bearer", UserSession@auth_token)),
-                 timeout(timeout)
-    )
 
-    return(parse(resp, "authentication"))
+    .Deprecated(msg = 'This function has been removed in the latest release of the Cytobank API. The current Cytobank version can automatically close API connections.')
+    # Comment out the following code to remove the logout function.  12/1/2020
+    if(0){
+        resp <- POST(paste(UserSession@site, "/logout", sep=""),
+                     add_headers(Authorization=paste("Bearer", UserSession@auth_token)),
+                     timeout(timeout)
+        )
+
+        return(parse(resp, "authentication"))
+    }
+
 })
 
 
@@ -83,18 +99,21 @@ setGeneric("authentication.revoke_all_tokens", function(UserSession, timeout=Use
 #' @rdname authentication
 #' @aliases authentication.revoke_all_tokens
 #'
-#' @details \code{authentication.revoke_all_tokens} Invalidate all existing tokens for the user making this call.
-#' @examples \dontrun{authentication.revoke_all_tokens(cyto_session)
-#' }
+#' @details \code{authentication.revoke_all_tokens} This function has been deprecated. Invalidate all existing tokens for the user making this call.
+
 #' @export
 setMethod("authentication.revoke_all_tokens", signature(UserSession="UserSession"), function(UserSession, timeout=UserSession@short_timeout)
 {
+    .Deprecated(msg = 'This function has been removed in the latest release of the Cytobank API. The current Cytobank version can automatically close API connections.')
+    # Comment out the following code to remove the logout function.  12/1/2020
+    if(0){
     resp <- POST(paste(UserSession@site, "/revoke_tokens", sep=""),
                  add_headers(Authorization=paste("Bearer", UserSession@auth_token)),
                  timeout(timeout)
     )
 
     return(parse(resp, "authentication"))
+    }
 })
 
 
@@ -105,12 +124,14 @@ setGeneric("authentication.revoke_all_tokens_user", function(UserSession, user_i
 #' @rdname authentication
 #' @aliases authentication.revoke_all_tokens_user
 #'
-#' @details \code{authentication.revoke_all_tokens_user} Revoke all tokens for a given user. This endpoint only works for admins of the Cytobank site being accessed.
-#' @examples \dontrun{authentication.revoke_all_tokens_user(cyto_session)
-#' }
+#' @details \code{authentication.revoke_all_tokens_user} This function has been deprecated. Revoke all tokens for a given user. This endpoint only works for admins of the Cytobank site being accessed.
+
 #' @export
 setMethod("authentication.revoke_all_tokens_user", signature(UserSession="UserSession"), function(UserSession, user_id, timeout=UserSession@short_timeout)
 {
+    .Deprecated(msg = 'This function has been removed in the latest release of the Cytobank API. The current Cytobank version can automatically close API connections.')
+    # Comment out the following code to remove the logout function.  12/1/2020
+    if(0){
     resp <- POST(paste(UserSession@site, "/revoke_user_tokens", sep=""),
                  add_headers(Authorization=paste("Bearer", UserSession@auth_token)),
                  body=list(user_id=user_id),
@@ -119,5 +140,6 @@ setMethod("authentication.revoke_all_tokens_user", signature(UserSession="UserSe
     )
 
     return(parse(resp, "authentication"))
+    }
 })
 
