@@ -140,7 +140,7 @@ setMethod("citrus.download", signature(UserSession="UserSession", citrus="CITRUS
 
     download_status<-utils::download.file(url=parse(resp)$downloadUrl,
                                           destfile=file.path(directory,file_name),
-                                          method = 'auto', quiet = FALSE)
+                                          method = 'auto', quiet = FALSE, mode = 'wb')
 
 
     if(download_status!=0){
