@@ -134,7 +134,7 @@ setMethod("flowsom.download", signature(UserSession="UserSession", flowsom="Flow
 
     download_status<-utils::download.file(url=parse(resp)$downloadUrl,
                                           destfile=file.path(directory,file_name),
-                                          method = 'auto', quiet = FALSE)
+                                          method = 'auto', quiet = FALSE, mode = 'wb')
 
     if(download_status!=0){
         print('Can not download the file.')
